@@ -34,9 +34,9 @@ struct cdk_verify_result_s {
     int sig_len;
     int sig_status;
     int sig_flags;
-    u32 keyid[2];
-    u32 created;
-    u32 expires;
+    unsigned long keyid[2];
+    unsigned long created;
+    unsigned long expires;
     int pubkey_algo;
     int digest_algo;
     char * notation;
