@@ -750,9 +750,13 @@ do_proc_packets( CDK_HD hd, CTX c, CDK_STREAM inp, CDK_STREAM * ret_out )
             /* skip rest of the packet */
             if (!c->s)
                 c->s = inp;
-            npos = cdk_stream_tell (c->s) + pkt->pkt.plaintext->len;
-            cdk_stream_seek (c->s, npos);
-            set_reset (c, c->s);
+            if( !_cdk_stream_get_blockmode( c->s ) ) {
+                npos = cdk_stream_tell (c->s) + pkt->pkt.plaintext->len;
+                cdk_stream_seek (c->s, npos);
+            }
+            else
+                cdk_stream_seek( c->s, cdk_stream_get_length( c->s ) );
+            set_reset( c, c->s );
             break;
           
         case CDK_PKT_SIGNATURE:
@@ -775,9 +779,9 @@ do_proc_packets( CDK_HD hd, CTX c, CDK_STREAM inp, CDK_STREAM * ret_out )
         if (rc)
             break;
     }
-    if (c->eof_seen == 1)
+    if( c->eof_seen == 1 )
         rc = 0;
-    for (node = c->node; !rc && node; node = node->next) {
+    for( node = c->node; !rc && node; node = node->next ) {
         pkt = node->pkt;
         switch (pkt->pkttype) {
         case CDK_PKT_ONEPASS_SIG:
@@ -802,7 +806,7 @@ do_proc_packets( CDK_HD hd, CTX c, CDK_STREAM inp, CDK_STREAM * ret_out )
         if (rc)
             break;
     }
-    if (rc == CDK_EOF)
+    if( rc == CDK_EOF )
         rc = CDK_Wrong_Seckey;
     return rc;
 }
@@ -945,8 +949,7 @@ cdk_data_transform( CDK_HD hd, int mode,
     CDK_STREAM inp, out;
     CDK_KEYDB_HD db;
     CDK_KBNODE knode = NULL;
-    size_t nlen;
-    int rc, nbytes = 0, res[4];
+    int rc, res[4];
     
     if( !hd )
         return CDK_Inv_Value;
@@ -1015,22 +1018,8 @@ cdk_data_transform( CDK_HD hd, int mode,
 
     cdk_stream_close( inp );
     if( !rc && mode != CDK_CRYPTYPE_VERIFY ) {
-        rc = cdk_stream_seek( out, 0 );
-        if( !rc )
-            rc = cdk_stream_flush( out );
-        if( !rc ) {
-            nlen = cdk_stream_get_length( out );
-            if( nlen ) {
-                *outbuf = cdk_calloc( 1, nlen + 1 );
-                *outsize = nlen;
-                if( !rc ) {
-                    cdk_stream_tmp_set_mode( out, 0 );
-                    nbytes = cdk_stream_read( out, *outbuf, nlen );
-                }
-                if( nbytes == CDK_EOF )
-                    rc = CDK_General_Error;
-            }
-        }
+        cdk_stream_tmp_set_mode( out, 0 );
+        rc = cdk_stream_mmap( out, outbuf, outsize );
     }
     else if( !rc && mode == CDK_CRYPTYPE_VERIFY ) {
         *outbuf = cdk_sig_get_info_as_xml( hd, modval );
