@@ -122,25 +122,31 @@ keydb_idx_build (const char * file)
 }
 
 
-static int
-keydb_idx_rebuild (CDK_KEYDB_HD hd)
+/**
+ * cdk_keydb_idx_rebuild:
+ * @hd: key database handle
+ *
+ * Rebuild the key index files for the given key database.
+ **/
+int
+cdk_keydb_idx_rebuild( CDK_KEYDB_HD hd )
 {
     int rc;
   
-    if (!hd || !hd->name)
+    if( !hd || !hd->name )
         return CDK_Inv_Value;
-    if (hd->secret)
+    if( hd->secret )
         return 0;
   
-    cdk_stream_close (hd->idx);
-    if (!hd->idx_name) {
-        hd->idx_name = keydb_idx_mkname (hd->name);
-        if (!hd->idx_name)
+    cdk_stream_close( hd->idx );
+    if( !hd->idx_name ) {
+        hd->idx_name = keydb_idx_mkname( hd->name );
+        if( !hd->idx_name )
             return CDK_Out_Of_Core;
     }
-    rc = keydb_idx_build (hd->name);
-    if (!rc)
-        rc = cdk_stream_open (hd->idx_name, &hd->idx);
+    rc = keydb_idx_build( hd->name );
+    if( !rc )
+        rc = cdk_stream_open( hd->idx_name, &hd->idx );
     return rc;
 }
 
@@ -219,6 +225,15 @@ keydb_idx_search (CDK_STREAM inp, u32 * keyid, const byte * fpr, u32 * r_off)
 }
 
 
+/**
+ * cdk_keydb_new:
+ * @r_hd: handle to store the new keydb object
+ * @type: type of the keyring
+ * @data: data which depends on the keyring type
+ * @count: length of the data
+ *
+ * Create a new keydb object
+ **/
 int
 cdk_keydb_new (CDK_KEYDB_HD * r_hd, int type, void * data, size_t count)
 {
@@ -260,6 +275,12 @@ cdk_keydb_new (CDK_KEYDB_HD * r_hd, int type, void * data, size_t count)
 }
 
 
+/**
+ * cdk_keydb_free:
+ * @hd: the keydb object
+ *
+ * Free the keydb object.
+ **/
 void
 cdk_keydb_free( CDK_KEYDB_HD hd )
 {
@@ -284,6 +305,13 @@ cdk_keydb_free( CDK_KEYDB_HD hd )
 }
 
 
+/**
+ * cdk_keydb_open:
+ * @hd: keydb object
+ * @ret_kr: the STREAM object which contains the data of the keyring
+ *
+ * Open a STREAM with the contents of the keyring from @hd
+ **/
 int
 cdk_keydb_open (CDK_KEYDB_HD hd, CDK_STREAM * ret_kr)
 {
@@ -388,7 +416,7 @@ find_by_fpr (CDK_KBNODE knode, CDK_DBSEARCH ks)
             || node->pkt->pkttype == CDK_PKT_PUBLIC_SUBKEY
             || node->pkt->pkttype == CDK_PKT_SECRET_KEY
             || node->pkt->pkttype == CDK_PKT_SECRET_SUBKEY) {
-            _cdk_fingerprint_get (node->pkt, fpr);
+            _cdk_pkt_get_fingerprint (node->pkt, fpr);
             if (!memcmp (ks->u.fpr, fpr, 20)) {
                 key_found = 1;
                 break;
@@ -543,24 +571,35 @@ keydb_search_copy (CDK_DBSEARCH * r_dst, CDK_DBSEARCH src)
     return 0;
 }
 
-  
+
+/**
+ * cdk_keydb_search_new:
+ * @r_dbs: object to store the new keydb search object
+ * @type: specifies the search type
+ * @desc: description which depends on the type
+ *
+ * Create a new keydb search object.
+ **/
 int
 cdk_keydb_search_new (CDK_DBSEARCH * r_dbs, int type, void * desc)
 {
     CDK_DBSEARCH dbs;
     u32 * keyid;
 
-    dbs = cdk_calloc (1, sizeof *dbs);
-    if (!dbs)
+    if( !r_dbs || !desc )
+        return CDK_Inv_Value;
+    
+    dbs = cdk_calloc( 1, sizeof *dbs );
+    if( !dbs )
         return CDK_Out_Of_Core;
     dbs->type = type;
-    switch (type) {
+    switch( type ) {
     case CDK_DBSEARCH_EXACT:
     case CDK_DBSEARCH_SUBSTR:
-        cdk_free (dbs->u.pattern);
-        dbs->u.pattern = cdk_strdup (desc);
-        if (!dbs->u.pattern) {
-            cdk_free (dbs);
+        cdk_free( dbs->u.pattern );
+        dbs->u.pattern = cdk_strdup( desc );
+        if( !dbs->u.pattern ) {
+            cdk_free( dbs );
             return CDK_Out_Of_Core;
         }
         break;
@@ -577,29 +616,33 @@ cdk_keydb_search_new (CDK_DBSEARCH * r_dbs, int type, void * desc)
         break;
 
     case CDK_DBSEARCH_FPR:
-        memcpy (dbs->u.fpr, desc, 20);
+        memcpy( dbs->u.fpr, desc, 20 );
         break;
 
     default:
-        cdk_free (dbs);
+        cdk_free( dbs );
         return CDK_Inv_Mode;
     }
-    if (r_dbs)
-        *r_dbs = dbs;
+    *r_dbs = dbs;
     return 0;
 }
 
 
+/**
+ * cdk_keydb_search_free:
+ * @dbs: the keydb search object
+ *
+ * Free the keydb oject.
+ **/
 void
 cdk_keydb_search_free (CDK_DBSEARCH dbs)
 {
     if( !dbs )
         return;
-    if (dbs->type == CDK_DBSEARCH_EXACT
-        || dbs->type == CDK_DBSEARCH_SUBSTR)
-        cdk_free (dbs->u.pattern);
+    if( dbs->type == CDK_DBSEARCH_EXACT || dbs->type == CDK_DBSEARCH_SUBSTR )
+        cdk_free( dbs->u.pattern );
     dbs->type = 0;
-    cdk_free (dbs);
+    cdk_free( dbs );
 }
 
 
@@ -643,77 +686,82 @@ keydb_pos_from_cache (CDK_KEYDB_HD hd, CDK_DBSEARCH ks,
 }
 
 
+/**
+ * cdk_keydb_search:
+ * @hd: the keydb object
+ * @ks: the keydb search object
+ * @ret_key: kbnode object to store the key
+ *
+ * Search for a key in the given keyring. The search mode is handled
+ * via @ks. If the key was found, @ret_key contains the key data.
+ **/
 int
-cdk_keydb_search (CDK_KEYDB_HD hd, CDK_DBSEARCH ks, CDK_KBNODE * r_key)
+cdk_keydb_search( CDK_KEYDB_HD hd, CDK_DBSEARCH ks, CDK_KBNODE * ret_key )
 {
-  CDK_STREAM kr = NULL;
-  CDK_KBNODE knode = NULL;
-  int key_found = 0, cache_hit = 0;
-  int rc = 0;
-  u32 off = 0;
-  size_t pos = 0;
+    CDK_STREAM kr = NULL;
+    CDK_KBNODE knode = NULL;
+    int key_found = 0, cache_hit = 0;
+    int rc = 0;
+    u32 off = 0;
+    size_t pos = 0;
 
-  if (!hd || !ks)
-    return CDK_Inv_Value;
+    if( !hd || !ks )
+        return CDK_Inv_Value;
 
-  if (r_key)
-    *r_key = NULL;
+    if( ret_key )
+        *ret_key = NULL;
 
-  rc = cdk_keydb_open (hd, &kr);
-  if (rc)
-    return rc;
+    rc = cdk_keydb_open( hd, &kr );
+    if( rc )
+        return rc;
 
-  rc = keydb_pos_from_cache (hd, ks, &cache_hit, &off);
-  if (rc)
-    return rc;
+    rc = keydb_pos_from_cache( hd, ks, &cache_hit, &off );
+    if( rc )
+        return rc;
 
-  while (!key_found && !rc)
-    {
-      if (cache_hit)
-        cdk_stream_seek (kr, off);
-      pos = cdk_stream_tell (kr);
-      rc = cdk_keydb_get_keyblock (kr, &knode);
-      if (rc)
-        {
-          if (rc == CDK_EOF && knode)
-            rc = 0;
-          if (!knode && rc == CDK_EOF)
-            rc = CDK_Error_No_Key;
-          if (rc)
-            break;
+    while( !key_found && !rc ) {
+        if( cache_hit )
+            cdk_stream_seek( kr, off );
+        pos = cdk_stream_tell( kr );
+        rc = cdk_keydb_get_keyblock( kr, &knode );
+        if( rc ) {
+            if( rc == CDK_EOF && knode )
+                rc = 0;
+            if( !knode && rc == CDK_EOF )
+                rc = CDK_Error_No_Key;
+            if( rc )
+                break;
         }
 
-      switch (ks->type)
-        {
+        switch (ks->type) {
         case CDK_DBSEARCH_SHORT_KEYID:
         case CDK_DBSEARCH_KEYID:
-          key_found = find_by_keyid (knode, ks);
-          break;
+            key_found = find_by_keyid (knode, ks);
+            break;
 
         case CDK_DBSEARCH_FPR:
-          key_found = find_by_fpr (knode, ks);
-          break;
+            key_found = find_by_fpr (knode, ks);
+            break;
           
 	case CDK_DBSEARCH_EXACT:
 	case CDK_DBSEARCH_SUBSTR:
-          key_found = find_by_pattern (knode, ks);
-	  break;
+            key_found = find_by_pattern (knode, ks);
+            break;
 	}
 
-      if (key_found)
-        {
-          if (!keydb_cache_find (hd->cache, ks))
-            keydb_cache_add (hd, ks, pos);
-          break;
+        if (key_found) {
+            if (!keydb_cache_find (hd->cache, ks))
+                keydb_cache_add (hd, ks, pos);
+            break;
         }
 
-      cdk_kbnode_release (knode);
-      knode = NULL;
+        cdk_kbnode_release (knode);
+        knode = NULL;
     }
 
-  if (r_key)
-    *r_key = key_found? knode : NULL;
-  return rc;
+    if( ret_key )
+        *ret_key = key_found? knode : NULL;
+    return rc;
 }
 
 
@@ -748,18 +796,18 @@ cdk_keydb_get_byfpr (CDK_KEYDB_HD hd, const byte * fpr, CDK_KBNODE * ret_pk)
 
 
 int
-cdk_keydb_get_bypattern (CDK_KEYDB_HD hd, const char *patt,
-			 CDK_KBNODE * ret_pk)
+cdk_keydb_get_bypattern (CDK_KEYDB_HD hd, const char * patt,
+			 CDK_KBNODE * ret_key)
 {
     struct cdk_keydb_search_s ks;
     int rc;
 
-    if (!hd || !patt || !ret_pk)
+    if (!hd || !patt || !ret_key)
         return CDK_Inv_Value;
 
     ks.type = CDK_DBSEARCH_SUBSTR;
     ks.u.pattern = cdk_strdup (patt);
-    rc = cdk_keydb_search (hd, &ks, ret_pk);
+    rc = cdk_keydb_search (hd, &ks, ret_key);
     cdk_free (ks.u.pattern);
     return rc;
 }
@@ -908,19 +956,19 @@ leave:
 
 
 int
-cdk_keydb_get_pk (CDK_KEYDB_HD hd, u32 * keyid, cdkPKT_public_key ** r_pk)
+cdk_keydb_get_pk( CDK_KEYDB_HD hd, u32 * keyid, cdkPKT_public_key ** r_pk )
 {
     struct cdk_keydb_search_s ks;
     CDK_KBNODE knode = NULL, node = NULL;
     cdkPKT_public_key * pk = NULL;
     int rc = 0;
 
-    if (!keyid)
+    if( !keyid )
         return CDK_Inv_Value;
-    if (!hd)
+    if( !hd )
         return CDK_Error_No_Keyring;
 
-    if (!keyid[0]) {
+    if( !keyid[0] ) {
         ks.type = CDK_DBSEARCH_SHORT_KEYID;
         ks.u.keyid[1] = keyid[1];
     }
@@ -929,19 +977,19 @@ cdk_keydb_get_pk (CDK_KEYDB_HD hd, u32 * keyid, cdkPKT_public_key ** r_pk)
         ks.u.keyid[0] = keyid[0];
         ks.u.keyid[1] = keyid[1];
     }
-    rc = cdk_keydb_search (hd, &ks, &knode);
-    if (rc)
+    rc = cdk_keydb_search( hd, &ks, &knode );
+    if( rc )
         goto leave;
-    node = keydb_find_bykeyid (knode, keyid);
-    if (!node) {
+    node = keydb_find_bykeyid( knode, keyid );
+    if( !node ) {
         rc = CDK_Error_No_Key;
         goto leave;
     }
-    _cdk_copy_pubkey (&pk, node->pkt->pkt.public_key);
-    cdk_kbnode_release (knode);
+    _cdk_copy_pubkey( &pk, node->pkt->pkt.public_key );
+    cdk_kbnode_release( knode );
 
- leave:
-    if (r_pk)
+leave:
+    if( r_pk )
         *r_pk = pk;
     return rc;
 }
@@ -1373,7 +1421,7 @@ fpr_from_str (const char * buf, byte * fpr)
 
 
 int
-cdk_keydb_search_auto (CDK_KEYDB_HD hd, const char *desc, CDK_KBNODE * r_knode)
+cdk_keydb_search_auto (CDK_KEYDB_HD hd, const char *desc, CDK_KBNODE * ret_key)
 {
     u32 keyid[2];
     byte fpr[20];
@@ -1386,18 +1434,18 @@ cdk_keydb_search_auto (CDK_KEYDB_HD hd, const char *desc, CDK_KBNODE * r_knode)
     switch (type) {
     case CDK_DBSEARCH_EXACT:
     case CDK_DBSEARCH_SUBSTR:
-        rc = cdk_keydb_get_bypattern (hd, desc, r_knode);
+        rc = cdk_keydb_get_bypattern (hd, desc, ret_key);
         break;
       
     case CDK_DBSEARCH_KEYID:
     case CDK_DBSEARCH_SHORT_KEYID:
         keyid_from_str (desc, keyid);
-        rc = cdk_keydb_get_bykeyid (hd, keyid, r_knode);
+        rc = cdk_keydb_get_bykeyid (hd, keyid, ret_key);
         break;
 
     case CDK_DBSEARCH_FPR:
         fpr_from_str (desc, fpr);
-        rc = cdk_keydb_get_byfpr (hd, fpr, r_knode);
+        rc = cdk_keydb_get_byfpr (hd, fpr, ret_key);
         break;
 
     default:
@@ -1524,11 +1572,11 @@ cdk_keydb_import (CDK_KEYDB_HD hd, CDK_KBNODE knode, int result[4])
         if (rc)
             break;
     }
-    if (!rc)
+    if( !rc )
         result[is_sk? 3 : 2] = 1;
-    cdk_stream_close (out);
-    if (!hd->no_cache)
-        keydb_idx_rebuild (hd);  
+    cdk_stream_close( out );
+    if( !hd->no_cache )
+        cdk_keydb_idx_rebuild( hd );
     return rc;
 }
 
