@@ -172,7 +172,7 @@ check_bits( int bits, int algo )
 {
     if( bits < 768 )
         return 768;
-    if( algo == GCRY_PK_DSA && bits > 1024 )
+    if( algo == CDK_PK_DSA && bits > 1024 )
         return 1024;
     if( bits > 4096 )
         return 4096;
