@@ -1,6 +1,6 @@
 /* -*- Mode: C; c-file-style: "bsd" -*- */
 /* new-packet.c - General packet handling (freeing, copying, ...)
- *       Copyright (C) 2001, 2002 Timo Schulz 
+ *       Copyright (C) 2001, 2002, 2003 Timo Schulz 
  *
  * This file is part of OpenCDK.
  *
@@ -34,10 +34,9 @@
 void
 _cdk_free_mpi_array (size_t n, GCRY_MPI * array)
 {
-  while (n--)
-    {
-      gcry_mpi_release (array[n]);
-      array[n] = NULL;
+    while (n--) {
+        gcry_mpi_release (array[n]);
+        array[n] = NULL;
     }
 }
 
@@ -45,15 +44,15 @@ _cdk_free_mpi_array (size_t n, GCRY_MPI * array)
 int
 cdk_pkt_new (CDK_PACKET ** r_pkt)
 {
-  CDK_PACKET *pkt;
+    CDK_PACKET *pkt;
 
-  pkt = cdk_calloc (1, sizeof *pkt);
-  if (!pkt)
-    return CDK_Out_Of_Core;
-  pkt->pkttype = 0;
-  *r_pkt = pkt;
+    pkt = cdk_calloc (1, sizeof *pkt);
+    if (!pkt)
+        return CDK_Out_Of_Core;
+    pkt->pkttype = 0;
+    *r_pkt = pkt;
 
-  return 0;
+    return 0;
 }
 
 
@@ -68,10 +67,9 @@ cdk_pkt_init( CDK_PACKET * pkt )
 static void
 free_symkey_enc (cdkPKT_symkey_enc * enc)
 {
-  if (enc)
-    {
-      cdk_free (enc->s2k);
-      cdk_free (enc);
+    if (enc) {
+        cdk_free (enc->s2k);
+        cdk_free (enc);
     }
 }
 
@@ -79,16 +77,14 @@ free_symkey_enc (cdkPKT_symkey_enc * enc)
 static void
 free_pubkey_enc (cdkPKT_pubkey_enc * enc)
 {
-  int nenc;
-  if (enc)
-    {
-      nenc = cdk_pk_get_nenc (enc->pubkey_algo);
-      while (enc->mpi && nenc--)
-        {
-          cdk_free (enc->mpi[nenc]);
-          enc->mpi[nenc] = NULL;
+    int nenc;
+    if (enc) {
+        nenc = cdk_pk_get_nenc (enc->pubkey_algo);
+        while (enc->mpi && nenc--) {
+            cdk_free (enc->mpi[nenc]);
+            enc->mpi[nenc] = NULL;
         }
-      cdk_free (enc);
+        cdk_free (enc);
     }
 }
 
@@ -96,21 +92,20 @@ free_pubkey_enc (cdkPKT_pubkey_enc * enc)
 static void
 free_plaintext (cdkPKT_plaintext *pt)
 {
-  if (pt)
-    cdk_free (pt);
+    if (pt)
+        cdk_free (pt);
 }
 
 
 void
 _cdk_free_userid (cdkPKT_user_id * uid)
 {
-  if (uid)
-    {
-      cdk_free (uid->prefs);
-      uid->prefs = NULL;
-      cdk_free (uid->attrib_img);
-      uid->attrib_img = NULL;      
-      cdk_free (uid);
+    if (uid) {
+        cdk_free (uid->prefs);
+        uid->prefs = NULL;
+        cdk_free (uid->attrib_img);
+        uid->attrib_img = NULL;      
+        cdk_free (uid);
     }
 }
 
@@ -118,20 +113,18 @@ _cdk_free_userid (cdkPKT_user_id * uid)
 void
 _cdk_free_signature (cdkPKT_signature * sig)
 {
-  int nsig;
-  if (sig)
-    {
-      nsig = cdk_pk_get_nsig (sig->pubkey_algo);
-      while (sig->mpi && nsig--)
-        {
-          cdk_free (sig->mpi[nsig]);
-          sig->mpi[nsig] = NULL;
+    int nsig;
+    if (sig) {
+        nsig = cdk_pk_get_nsig (sig->pubkey_algo);
+        while (sig->mpi && nsig--) {
+            cdk_free (sig->mpi[nsig]);
+            sig->mpi[nsig] = NULL;
         }
-      cdk_subpkt_free (sig->hashed);
-      sig->hashed = NULL;
-      cdk_subpkt_free (sig->unhashed);
-      sig->unhashed = NULL;
-      cdk_free (sig);
+        cdk_subpkt_free (sig->hashed);
+        sig->hashed = NULL;
+        cdk_subpkt_free (sig->unhashed);
+        sig->unhashed = NULL;
+        cdk_free (sig);
     }
 }
 
@@ -139,21 +132,18 @@ _cdk_free_signature (cdkPKT_signature * sig)
 void
 _cdk_free_pubkey (cdkPKT_public_key * pk)
 {
-  int npkey;
-  
-  if (pk)
-    {
-      npkey = cdk_pk_get_npkey (pk->pubkey_algo);
-      _cdk_free_userid (pk->uid);
-      pk->uid = NULL;
-      cdk_free (pk->prefs);
-      pk->prefs = NULL;
-      while (pk->mpi && npkey--)
-        {
-          cdk_free (pk->mpi[npkey]);
-          pk->mpi[npkey] = NULL; 
+    int npkey;
+    if (pk) {
+        npkey = cdk_pk_get_npkey (pk->pubkey_algo);
+        _cdk_free_userid (pk->uid);
+        pk->uid = NULL;
+        cdk_free (pk->prefs);
+        pk->prefs = NULL;
+        while (pk->mpi && npkey--) {
+            cdk_free (pk->mpi[npkey]);
+            pk->mpi[npkey] = NULL; 
         }
-      cdk_free (pk);
+        cdk_free (pk);
     }
 }
 
@@ -161,27 +151,24 @@ _cdk_free_pubkey (cdkPKT_public_key * pk)
 void
 _cdk_free_seckey (cdkPKT_secret_key * sk)
 {
-  int nskey;
+    int nskey;
   
-  if (sk)
-    {
-      nskey = cdk_pk_get_nskey (sk->pubkey_algo);
-      while (nskey--)
-        {
-          if (sk->mpi[nskey])
-            {
-              wipemem (sk->mpi[nskey], sk->mpi[nskey]->bytes);
-              cdk_free (sk->mpi[nskey]);
-              sk->mpi[nskey] = NULL;
+    if (sk) {
+        nskey = cdk_pk_get_nskey (sk->pubkey_algo);
+        while (nskey--) {
+            if (sk->mpi[nskey]) {
+                wipemem (sk->mpi[nskey], sk->mpi[nskey]->bytes);
+                cdk_free (sk->mpi[nskey]);
+                sk->mpi[nskey] = NULL;
             }
         }
-      cdk_free (sk->encdata);
-      sk->encdata = NULL;
-      _cdk_free_pubkey (sk->pk);
-      sk->pk = NULL;
-      cdk_free (sk->protect.s2k);
-      sk->protect.s2k = NULL;
-      cdk_free (sk);
+        cdk_free (sk->encdata);
+        sk->encdata = NULL;
+        _cdk_free_pubkey (sk->pk);
+        sk->pk = NULL;
+        cdk_free (sk->protect.s2k);
+        sk->protect.s2k = NULL;
+        cdk_free (sk);
     }
 }
 
@@ -189,11 +176,10 @@ _cdk_free_seckey (cdkPKT_secret_key * sk)
 static void
 free_encrypted (cdkPKT_encrypted *enc)
 {
-  if (enc)
-    {
-      cdk_stream_close (enc->buf);
-      enc->buf = NULL;
-      cdk_free (enc);
+    if (enc) {
+        cdk_stream_close (enc->buf);
+        enc->buf = NULL;
+        cdk_free (enc);
     }
 }
 
@@ -228,10 +214,9 @@ cdk_pkt_free (CDK_PACKET * pkt)
 void
 cdk_pkt_release (CDK_PACKET * pkt)
 {
-  if (pkt)
-    {
-      cdk_pkt_free (pkt);
-      cdk_free (pkt);
+    if (pkt) {
+        cdk_pkt_free (pkt);
+        cdk_free (pkt);
     }
 }
 
@@ -367,20 +352,20 @@ _cdk_copy_prefs (const struct cdk_prefitem_s * prefs)
 int
 _cdk_copy_userid (cdkPKT_user_id ** dst, cdkPKT_user_id * src)
 {
-  cdkPKT_user_id *u;
+    cdkPKT_user_id *u;
 
-  if (!dst || !src)
-    return CDK_Inv_Value;
+    if (!dst || !src)
+        return CDK_Inv_Value;
 
-  u = cdk_calloc (1, sizeof *u + strlen (src->name) + 1);
-  if (!u)
-    return CDK_Out_Of_Core;
-  memcpy (u, src, sizeof *u);
-  memcpy (u->name, src->name, strlen (src->name));
-  u->prefs = _cdk_copy_prefs (src->prefs);
-  *dst = u;
+    u = cdk_calloc (1, sizeof *u + strlen (src->name) + 1);
+    if (!u)
+        return CDK_Out_Of_Core;
+    memcpy (u, src, sizeof *u);
+    memcpy (u->name, src->name, strlen (src->name));
+    u->prefs = _cdk_copy_prefs (src->prefs);
+    *dst = u;
 
-  return 0;
+    return 0;
 }
 
 
