@@ -210,30 +210,28 @@ _cdk_pkt_read_len (FILE * inp, int * ret_partial)
 
 
 static int
-read_encrypted (CDK_STREAM inp, size_t pktlen, cdkPKT_encrypted * enc,
-		int partial, int mdc)
+read_encrypted( CDK_STREAM inp, size_t pktlen, cdkPKT_encrypted * enc,
+		int partial, int mdc )
 {
     int rc = 0, version;
 
-    if (!inp || !enc)
+    if( !inp || !enc )
         return CDK_Inv_Value;
 
-    if (DEBUG_PKT)
-        _cdk_log_debug ("** read encrypted packet %d bytes\n", pktlen);
+    if( DEBUG_PKT )
+        _cdk_log_debug( "** read encrypted packet %d bytes\n", pktlen );
 
-    if (mdc) {
-        version = stream_getc (inp);
-        if (version != 1)
+    if( mdc ) {
+        version = stream_getc( inp );
+        if( version != 1 )
             return CDK_Inv_Packet;
-        enc->mdc_method = GCRY_MD_SHA1;
+        enc->mdc_method = CDK_MD_SHA1;
         pktlen--;
     }
-    if (pktlen < 10)
+    if( pktlen < 10 )
         return CDK_Inv_Packet; /* we need at least blocksize + 2 bytes */
-
-    if (partial)
-        _cdk_stream_set_blockmode (inp, pktlen);
-    /*enc->len = cdk_stream_get_length (enc->buf) - cdk_stream_tell (inp);*/
+    if( partial )
+        _cdk_stream_set_blockmode( inp, pktlen );
     enc->len = pktlen;
     enc->buf = inp;
     return rc;
@@ -740,12 +738,12 @@ read_signature( CDK_STREAM inp, size_t pktlen, cdkPKT_signature * sig )
             size -= nbytes;
         }
       
-        sig->unhashed_size = read_16 (inp);
+        sig->unhashed_size = read_16( inp );
         size = sig->unhashed_size;
         sig->unhashed = NULL;
-        while (size > 0) {
-            rc = read_subpkt (inp, &sig->unhashed, &nbytes);
-            if (rc)
+        while( size > 0 ) {
+            rc = read_subpkt( inp, &sig->unhashed, &nbytes );
+            if( rc )
                 break;
             size -= nbytes;
 	}
@@ -762,21 +760,21 @@ read_signature( CDK_STREAM inp, size_t pktlen, cdkPKT_signature * sig )
                 sig->flags.exportable = 0;
 	    }
 	}
-        for (node = sig->hashed; node; node = node->next) {
-            if (node->type == SIGSUBPKT_SIG_CREATED)
-                sig->timestamp = _cdk_buftou32 (node->d);
-            else if (node->type == SIGSUBPKT_SIG_EXPIRE) {
+        for( node = sig->hashed; node; node = node->next ) {
+            if( node->type == SIGSUBPKT_SIG_CREATED )
+                sig->timestamp = _cdk_buftou32( node->d );
+            else if( node->type == SIGSUBPKT_SIG_EXPIRE ) {
                 sig->expiredate = _cdk_buftou32 (node->d);
                 if (sig->expiredate > 0 && sig->expiredate < _cdk_timestamp ())
                     sig->flags.expired = 1;
 	    }
-            else if (node->type == SIGSUBPKT_POLICY)
+            else if( node->type == SIGSUBPKT_POLICY )
                 sig->flags.policy_url = 1;
-            else if (node->type == SIGSUBPKT_NOTATION)
+            else if( node->type == SIGSUBPKT_NOTATION )
                 sig->flags.notation = 1;
-            else if (node->type == SIGSUBPKT_REVOCABLE && node->d[0] == 0)
+            else if( node->type == SIGSUBPKT_REVOCABLE && node->d[0] == 0 )
                 sig->flags.revocable = 0;
-            else if (node->type == SIGSUBPKT_EXPORTABLE && node->d[0] == 0)
+            else if( node->type == SIGSUBPKT_EXPORTABLE && node->d[0] == 0 )
                 sig->flags.exportable = 0;
 	}
         sig->digest_start[0] = stream_getc( inp );
@@ -795,34 +793,39 @@ read_signature( CDK_STREAM inp, size_t pktlen, cdkPKT_signature * sig )
 
 
 static int
-read_plaintext (CDK_STREAM inp, size_t pktlen, cdkPKT_plaintext * pt)
+read_plaintext( CDK_STREAM inp, size_t pktlen, cdkPKT_plaintext ** ret_pt,
+                int partial )
 {
+    cdkPKT_plaintext * pt = *ret_pt;
     size_t nread = 0;
     int rc = 0;
 
-    if (!inp || !pt)
+    if( !inp || !pt )
         return CDK_Inv_Value;
 
-    if (DEBUG_PKT)
-        _cdk_log_debug ("** read plaintext packet\n");
+    if( DEBUG_PKT )
+        _cdk_log_debug( "** read plaintext packet\n" );
 
-    pt->mode = stream_getc (inp);
-    if (pt->mode != 0x62 && pt->mode != 0x74)
+    pt->mode = stream_getc( inp );
+    if( pt->mode != 0x62 && pt->mode != 0x74 )
         return CDK_Inv_Packet;
-    pt->namelen = stream_getc (inp);
-    if (pt->namelen) {
-        rc = stream_read (inp, pt->name, pt->namelen, &nread);
-        if (!rc && nread != pt->namelen)
+    pt->namelen = stream_getc( inp );
+    if( pt->namelen ) {
+        *ret_pt = pt = cdk_realloc( pt, sizeof * pt + pt->namelen + 1 );
+        if( !pt )
+            return CDK_Out_Of_Core;
+        rc = stream_read( inp, pt->name, pt->namelen, &nread );
+        if( !rc && nread != pt->namelen )
             return CDK_Inv_Packet;
         pt->name[pt->namelen] = '\0';
     }
-    pt->timestamp = read_32 (inp);
+    pt->timestamp = read_32( inp );
     pktlen -= 6;
     pktlen -= pt->namelen;
-    if (pktlen) { 
-        pt->buf = inp;
-        pt->len = pktlen;
-    }
+    if( partial )
+        _cdk_stream_set_blockmode( inp, pktlen );
+    pt->buf = inp;
+    pt->len = pktlen;
     return rc;
 }
 
@@ -995,11 +998,10 @@ cdk_pkt_parse (CDK_STREAM inp, CDK_PACKET * pkt)
         break;
 
     case CDK_PKT_PLAINTEXT:
-        pkt->pkt.plaintext = cdk_calloc (1, sizeof *pkt->pkt.plaintext
-                                         + pkt->pktlen);
+        pkt->pkt.plaintext = cdk_calloc( 1, sizeof *pkt->pkt.plaintext );
         if (!pkt->pkt.plaintext)
             return CDK_Out_Of_Core;
-        rc = read_plaintext (inp, pkth.len, pkt->pkt.plaintext);
+        rc = read_plaintext( inp, pkth.len, &pkt->pkt.plaintext, pkth.partial);
         break;
 
     case CDK_PKT_ONEPASS_SIG:
