@@ -116,17 +116,17 @@ int
 _cdk_sig_complete( cdkPKT_signature * sig, cdkPKT_secret_key * sk,
                    GCRY_MD_HD md )
 {
-  byte digest[24];
+    byte digest[24];
 
-  if( !sig || !sk )
-    return CDK_Inv_Value;
+    if( !sig || !sk || !md )
+        return CDK_Inv_Value;
   
-  sig_calc_subpkt_size( sig );
-  _cdk_hash_sig_data( sig, md );
-  gcry_md_final( md );
-  memcpy( digest, gcry_md_read( md, sig->digest_algo),
-          gcry_md_get_algo_dlen( sig->digest_algo ) );
-  return cdk_pk_sign( sk, sig, digest );
+    sig_calc_subpkt_size( sig );
+    _cdk_hash_sig_data( sig, md );
+    gcry_md_final( md );
+    memcpy( digest, gcry_md_read( md, sig->digest_algo),
+            gcry_md_get_algo_dlen( sig->digest_algo ) );
+    return cdk_pk_sign( sk, sig, digest );
 }
 
 
@@ -167,7 +167,7 @@ write_pubkey_enc_list( CDK_HD hd, CDK_STREAM out, CDK_STRLIST remusr )
     CDK_KEYLIST pkl;
     int rc;
 
-    if( !out)
+    if( !hd || !out )
         return CDK_Inv_Value;
   
     rc = cdk_pklist_build( hd->db.pub, remusr, &pkl, GCRY_PK_USAGE_ENCR );
@@ -194,7 +194,7 @@ sig_get_version( CDK_HD hd, CDK_KEYLIST kl )
 {
     CDK_KEYLIST l;
 
-    if( hd->opt.compat )
+    if( hd && hd->opt.compat )
         return 3;
   
     for( l = kl; l; l = l->next ) {
@@ -247,6 +247,9 @@ cdk_stream_sign( CDK_HD hd, CDK_STREAM inp, CDK_STREAM out,
     int sigver, digest_algo;
     int rc, detached = sigmode == CDK_SIGMODE_DETACHED;
 
+    if( !hd )
+        return CDK_Inv_Value;
+    
     if( sigmode == CDK_SIGMODE_CLEAR )
         return stream_clearsign( hd, inp, out, locusr );
     
