@@ -1,6 +1,6 @@
 /* -*- Mode: C; c-file-style: "bsd" -*- */
 /* stream.c - provides a STREAM object
- *        Copyright (C) 2002 Timo Schulz
+ *        Copyright (C) 2002, 2003 Timo Schulz
  *
  * This file is part of OpenCDK.
  *
@@ -22,6 +22,7 @@
 #ifdef HAVE_CONFIG_H
 # include <config.h>
 #endif
+#include <assert.h>
 #include <stdio.h>
 #include <sys/stat.h>
 #include <string.h>
@@ -399,6 +400,8 @@ filter_add( CDK_STREAM s )
 {
     struct stream_filter_s * f;
 
+    assert( s );
+    
     f = cdk_calloc( 1, sizeof *f );
     if( !f )
         return NULL;
@@ -413,6 +416,8 @@ filter_search( CDK_STREAM s, FILTER_FUNC fnc )
 {
     struct stream_filter_s * f;
 
+    assert( s );
+    
     for( f = s->filters; f; f = f->next ) {
         if( f->fnc == fnc )
             return f;
@@ -454,6 +459,8 @@ stream_filter_add( CDK_STREAM s, FILTER_FUNC fnc, int type)
 static int
 stream_get_mode( CDK_STREAM s )
 {
+    assert( s );
+    
     if( s->flags.temp )
         return s->fmode;
     return s->flags.write;
@@ -499,14 +506,16 @@ cdk_stream_filter_disable( CDK_STREAM s, int type )
 static int
 stream_fp_replace( CDK_STREAM s, FILE ** tmp )
 {
-  int rc;
+    int rc;
+
+    assert( s );
   
-  rc = fclose( s->fp );
-  if( rc )
-    return CDK_File_Error;
-  s->fp = *tmp;
-  *tmp = NULL;
-  return 0;
+    rc = fclose( s->fp );
+    if( rc )
+        return CDK_File_Error;
+    s->fp = *tmp;
+    *tmp = NULL;
+    return 0;
 }
 
 
@@ -518,7 +527,9 @@ stream_filter_write( CDK_STREAM s )
 {
     struct stream_filter_s * f;
     int rc = 0;
-  
+
+    assert( s );
+    
     if( s->flags.filtrated )
         return CDK_Inv_Value;
 
@@ -569,7 +580,9 @@ stream_filter_read( CDK_STREAM s )
 {
     struct stream_filter_s * f;
     int rc = 0;
-  
+
+    assert( s );
+    
     if( s->flags.filtrated )
         return 0;
 
@@ -768,8 +781,8 @@ stream_flush( CDK_STREAM s )
 {
     int rc;
     
-    if( !s )
-        return CDK_Inv_Value;
+    assert( s );
+    
     rc = fflush( s->fp  );
     if( rc )
         rc = CDK_File_Error;
@@ -804,8 +817,12 @@ cdk_stream_set_literal_flag( CDK_STREAM s, int mode, const char * fname )
     if( !flt )
         return CDK_Out_Of_Core;
     flt->u.pfx.mode = mode;
-    flt->u.pfx.filename = fname? cdk_strdup( fname) : NULL;
+    flt->u.pfx.filename = fname? cdk_strdup( fname ) : NULL;
     flt->ctl = stream_get_mode( s );
+    if( s->blkmode ) {
+        flt->u.pfx.blkmode.on = 1;
+        flt->u.pfx.blkmode.size = s->blkmode;
+    }
     return 0;
 }
 
@@ -901,8 +918,8 @@ stream_cache_flush( CDK_STREAM s, FILE * fp )
 {
     int nwritten;
 
-    if( !s )
-        return CDK_Inv_Value;
+    assert( s );
+    
     if( s->cache.size > 0 ) {
         nwritten = fwrite( s->cache.buf, 1, s->cache.size, fp  );
         if( !nwritten )
@@ -937,6 +954,45 @@ cdk_stream_kick_off( CDK_STREAM inp, CDK_STREAM out )
 }
 
 
+/**
+ * cdk_stream_mmap:
+ * @s: the stream
+ * @ret_buf: the buffer to store the content
+ * @ret_count: length of the buffer
+ *
+ * Map the data of the given stream into a memory section. @ret_count
+ * contains the length of the buffer.
+ **/
+int
+cdk_stream_mmap( CDK_STREAM s, byte ** ret_buf, size_t * ret_count )
+{
+    const u32 max_filesize = 16777216;
+    u32 len, oldpos;
+    int n;
+
+    if( !s || !ret_buf || !ret_count )
+        return CDK_Inv_Value;
+
+    *ret_count = 0;
+    *ret_buf = NULL;
+    oldpos = cdk_stream_tell( s );
+    cdk_stream_flush( s );
+    cdk_stream_seek( s, 0 );
+    len = cdk_stream_get_length( s );
+    if( !len || len > max_filesize )
+        return 0;
+    *ret_buf = cdk_calloc( 1, len+1 );
+    if( !*ret_buf )
+        return 0;
+    *ret_count = len;
+    n = cdk_stream_read( s, *ret_buf, len );
+    if( n != len )
+        *ret_count = n;
+    cdk_stream_seek( s, oldpos );
+    return 0;
+}
+        
+
 int
 _cdk_stream_gets( CDK_STREAM s, char * buf, size_t count )
 {
@@ -973,3 +1029,12 @@ _cdk_stream_set_blockmode( CDK_STREAM s, size_t nbytes )
     s->blkmode = nbytes;  
     return 0;
 }
+
+
+int
+_cdk_stream_get_blockmode( CDK_STREAM s )
+{
+    return s? s->blkmode : 0;
+}
+
+    
