@@ -647,7 +647,7 @@ test_verify (int argc, char ** argv)
     CDK_HD hd;
     CDK_KEYDB_HD db;
     int rc;
-    char * s = "/home/twoaday/.gnupg/pubring.gpg";
+    char * s = "/home/twoaday/.gnupg/pubring.cdk";
     const char * st =
         "-----BEGIN PGP MESSAGE-----\n"
         "Version: OpenPrivacy 0.4.2-cvs\n"
@@ -769,10 +769,10 @@ int
 main (int argc, char ** argv)
 {
     /*test_encrypt (argc, argv);*/
-    /*test_decrypt (argc, argv);*/
+    test_decrypt (argc, argv);
     /*test_sign (argc, argv);*/
     /*test_verify (argc, argv);*/
-    test_import (argc, argv);
+    /*test_import (argc, argv);*/
     return 0;
 }
 
